@@ -43,4 +43,8 @@ def remove_dirtree(dir):
 
 def remove_file(path):
     if os.path.exists(path):  
-        os.remove(path)
\ No newline at end of file
+        os.remove(path)
+
+
+def project_layout(project_dir):
+    return os.path.join(project_dir, 'layout.json')
\ No newline at end of file
